/*
 	File:		CMScriptingPlugin.h
 
 	Contains:	ColorSync Scripting Plugin API
 
 	Version:	Technology:	ColorSync 2.5
 				Release:	ColorSync 2.6 SDK for use with Universal Interfaces 3.1
 
 	Copyright:	 1998 by Apple Computer, Inc., all rights reserved.
 
 	Bugs?:		For bug reports, consult the following page on
 				the World Wide Web:
 
 					http://developer.apple.com/bugreporter/
 
*/
#ifndef __CMSCRIPTINGPLUGIN__
#define __CMSCRIPTINGPLUGIN__

#ifndef __FILES__
#include <Files.h>
#endif
#ifndef __CMAPPLICATION__
#include <CMApplication.h>
#endif
#ifndef __CODEFRAGMENTS__
#include <CodeFragments.h>
#endif





#if PRAGMA_ONCE
#pragma once
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if PRAGMA_IMPORT
#pragma import on
#endif

#if PRAGMA_STRUCT_ALIGN
	#pragma options align=mac68k
#elif PRAGMA_STRUCT_PACKPUSH
	#pragma pack(push, 2)
#elif PRAGMA_STRUCT_PACK
	#pragma pack(2)
#endif


enum {
																/* ColorSync Scripting AppleEvent Errors */
	cmspInvalidImageFile		= -4220,						/* Plugin cannot handle this image file type */
	cmspInvalidImageSpace		= -4221,						/* Plugin cannot create an image file of this colorspace */
	cmspInvalidProfileEmbed		= -4222,						/* Specific invalid profile errors */
	cmspInvalidProfileSource	= -4223,
	cmspInvalidProfileDest		= -4224,
	cmspInvalidProfileProof		= -4225,
	cmspInvalidProfileLink		= -4226
};


/**** embedFlags field  ****/
/* reserved for future use: currently 0 */

/**** matchFlags field  ****/

enum {
	cmspFavorEmbeddedMask		= 0x00000001					/* if bit 0 is 0 then use srcProf profile, if 1 then use profile embedded in image if present*/
};


/**** scripting plugin entry points  ****/
typedef CALLBACK_API_C( CMError , ValidateImageProcPtr )(const FSSpec *spec);
typedef CALLBACK_API_C( CMError , GetImageSpaceProcPtr )(const FSSpec *spec, OSType *space);
typedef CALLBACK_API_C( CMError , ValidateSpaceProcPtr )(const FSSpec *spec, OSType *space);
typedef CALLBACK_API_C( CMError , EmbedImageProcPtr )(const FSSpec *specFrom, const FSSpec *specInto, CMProfileRef embedProf, UInt32 embedFlags);
typedef CALLBACK_API_C( CMError , UnembedImageProcPtr )(const FSSpec *specFrom, const FSSpec *specInto);
typedef CALLBACK_API_C( CMError , MatchImageProcPtr )(const FSSpec *specFrom, const FSSpec *specInto, UInt32 qual, UInt32 srcIntent, CMProfileRef srcProf, CMProfileRef dstProf, CMProfileRef prfProf, UInt32 matchFlags);
typedef CALLBACK_API_C( CMError , CountImageProfilesProcPtr )(const FSSpec *spec, UInt32 *count);
typedef CALLBACK_API_C( CMError , GetIndImageProfileProcPtr )(const FSSpec *spec, UInt32 index, CMProfileRef *prof);
typedef CALLBACK_API_C( CMError , SetIndImageProfileProcPtr )(const FSSpec *specFrom, const FSSpec *specInto, UInt32 index, CMProfileRef prof, UInt32 embedFlags);
/**** CSScriptingLib entry points  ****/
typedef CALLBACK_API_C( CMError , CMValidImageProcPtr )(const FSSpec *spec);
typedef CALLBACK_API_C( CMError , CMGetImageSpaceProcPtr )(const FSSpec *spec, OSType *space);
typedef CALLBACK_API_C( CMError , CMEmbedImageProcPtr )(const FSSpec *specFrom, const FSSpec *specInto, Boolean repl, CMProfileRef embProf);
typedef CALLBACK_API_C( CMError , CMUnembedImageProcPtr )(const FSSpec *specFrom, const FSSpec *specInto, Boolean repl);
typedef CALLBACK_API_C( CMError , CMMatchImageProcPtr )(const FSSpec *specFrom, const FSSpec *specInto, Boolean repl, UInt32 qual, CMProfileRef srcProf, UInt32 srcIntent, CMProfileRef dstProf);
typedef CALLBACK_API_C( CMError , CMProofImageProcPtr )(const FSSpec *specFrom, const FSSpec *specInto, Boolean repl, UInt32 qual, CMProfileRef srcProf, UInt32 srcIntent, CMProfileRef dstProf, CMProfileRef prfProf);
typedef CALLBACK_API_C( CMError , CMLinkImageProcPtr )(const FSSpec *specFrom, const FSSpec *specInto, Boolean repl, UInt32 qual, CMProfileRef lnkProf, UInt32 lnkIntent);
typedef CALLBACK_API_C( CMError , CMCountImageProfilesProcPtr )(const FSSpec *spec, UInt32 *count);
typedef CALLBACK_API_C( CMError , CMGetIndImageProfileProcPtr )(const FSSpec *spec, UInt32 index, CMProfileRef *prof);
typedef CALLBACK_API_C( CMError , CMSetIndImageProfileProcPtr )(const FSSpec *specFrom, const FSSpec *specInto, Boolean repl, UInt32 index, CMProfileRef prof);
typedef STACK_UPP_TYPE(ValidateImageProcPtr) 					ValidateImageUPP;
typedef STACK_UPP_TYPE(GetImageSpaceProcPtr) 					GetImageSpaceUPP;
typedef STACK_UPP_TYPE(ValidateSpaceProcPtr) 					ValidateSpaceUPP;
typedef STACK_UPP_TYPE(EmbedImageProcPtr) 						EmbedImageUPP;
typedef STACK_UPP_TYPE(UnembedImageProcPtr) 					UnembedImageUPP;
typedef STACK_UPP_TYPE(MatchImageProcPtr) 						MatchImageUPP;
typedef STACK_UPP_TYPE(CountImageProfilesProcPtr) 				CountImageProfilesUPP;
typedef STACK_UPP_TYPE(GetIndImageProfileProcPtr) 				GetIndImageProfileUPP;
typedef STACK_UPP_TYPE(SetIndImageProfileProcPtr) 				SetIndImageProfileUPP;
typedef STACK_UPP_TYPE(CMValidImageProcPtr) 					CMValidImageUPP;
typedef STACK_UPP_TYPE(CMGetImageSpaceProcPtr) 					CMGetImageSpaceUPP;
typedef STACK_UPP_TYPE(CMEmbedImageProcPtr) 					CMEmbedImageUPP;
typedef STACK_UPP_TYPE(CMUnembedImageProcPtr) 					CMUnembedImageUPP;
typedef STACK_UPP_TYPE(CMMatchImageProcPtr) 					CMMatchImageUPP;
typedef STACK_UPP_TYPE(CMProofImageProcPtr) 					CMProofImageUPP;
typedef STACK_UPP_TYPE(CMLinkImageProcPtr) 						CMLinkImageUPP;
typedef STACK_UPP_TYPE(CMCountImageProfilesProcPtr) 			CMCountImageProfilesUPP;
typedef STACK_UPP_TYPE(CMGetIndImageProfileProcPtr) 			CMGetIndImageProfileUPP;
typedef STACK_UPP_TYPE(CMSetIndImageProfileProcPtr) 			CMSetIndImageProfileUPP;
enum { uppValidateImageProcInfo = 0x000000F1 }; 				/* 4_bytes Func(4_bytes) */
enum { uppGetImageSpaceProcInfo = 0x000003F1 }; 				/* 4_bytes Func(4_bytes, 4_bytes) */
enum { uppValidateSpaceProcInfo = 0x000003F1 }; 				/* 4_bytes Func(4_bytes, 4_bytes) */
enum { uppEmbedImageProcInfo = 0x00003FF1 }; 					/* 4_bytes Func(4_bytes, 4_bytes, 4_bytes, 4_bytes) */
enum { uppUnembedImageProcInfo = 0x000003F1 }; 					/* 4_bytes Func(4_bytes, 4_bytes) */
enum { uppMatchImageProcInfo = 0x003FFFF1 }; 					/* 4_bytes Func(4_bytes, 4_bytes, 4_bytes, 4_bytes, 4_bytes, 4_bytes, 4_bytes, 4_bytes) */
enum { uppCountImageProfilesProcInfo = 0x000003F1 }; 			/* 4_bytes Func(4_bytes, 4_bytes) */
enum { uppGetIndImageProfileProcInfo = 0x00000FF1 }; 			/* 4_bytes Func(4_bytes, 4_bytes, 4_bytes) */
enum { uppSetIndImageProfileProcInfo = 0x0000FFF1 }; 			/* 4_bytes Func(4_bytes, 4_bytes, 4_bytes, 4_bytes, 4_bytes) */
enum { uppCMValidImageProcInfo = 0x000000F1 }; 					/* 4_bytes Func(4_bytes) */
enum { uppCMGetImageSpaceProcInfo = 0x000003F1 }; 				/* 4_bytes Func(4_bytes, 4_bytes) */
enum { uppCMEmbedImageProcInfo = 0x000037F1 }; 					/* 4_bytes Func(4_bytes, 4_bytes, 1_byte, 4_bytes) */
enum { uppCMUnembedImageProcInfo = 0x000007F1 }; 				/* 4_bytes Func(4_bytes, 4_bytes, 1_byte) */
enum { uppCMMatchImageProcInfo = 0x000FF7F1 }; 					/* 4_bytes Func(4_bytes, 4_bytes, 1_byte, 4_bytes, 4_bytes, 4_bytes, 4_bytes) */
enum { uppCMProofImageProcInfo = 0x003FF7F1 }; 					/* 4_bytes Func(4_bytes, 4_bytes, 1_byte, 4_bytes, 4_bytes, 4_bytes, 4_bytes, 4_bytes) */
enum { uppCMLinkImageProcInfo = 0x0003F7F1 }; 					/* 4_bytes Func(4_bytes, 4_bytes, 1_byte, 4_bytes, 4_bytes, 4_bytes) */
enum { uppCMCountImageProfilesProcInfo = 0x000003F1 }; 			/* 4_bytes Func(4_bytes, 4_bytes) */
enum { uppCMGetIndImageProfileProcInfo = 0x00000FF1 }; 			/* 4_bytes Func(4_bytes, 4_bytes, 4_bytes) */
enum { uppCMSetIndImageProfileProcInfo = 0x0000F7F1 }; 			/* 4_bytes Func(4_bytes, 4_bytes, 1_byte, 4_bytes, 4_bytes) */
#if MIXEDMODE_CALLS_ARE_FUNCTIONS
EXTERN_API(ValidateImageUPP)
NewValidateImageProc		   (ValidateImageProcPtr	userRoutine);
EXTERN_API(GetImageSpaceUPP)
NewGetImageSpaceProc		   (GetImageSpaceProcPtr	userRoutine);
EXTERN_API(ValidateSpaceUPP)
NewValidateSpaceProc		   (ValidateSpaceProcPtr	userRoutine);
EXTERN_API(EmbedImageUPP)
NewEmbedImageProc			   (EmbedImageProcPtr		userRoutine);
EXTERN_API(UnembedImageUPP)
NewUnembedImageProc			   (UnembedImageProcPtr		userRoutine);
EXTERN_API(MatchImageUPP)
NewMatchImageProc			   (MatchImageProcPtr		userRoutine);
EXTERN_API(CountImageProfilesUPP)
NewCountImageProfilesProc	   (CountImageProfilesProcPtr userRoutine);
EXTERN_API(GetIndImageProfileUPP)
NewGetIndImageProfileProc	   (GetIndImageProfileProcPtr userRoutine);
EXTERN_API(SetIndImageProfileUPP)
NewSetIndImageProfileProc	   (SetIndImageProfileProcPtr userRoutine);
EXTERN_API(CMValidImageUPP)
NewCMValidImageProc			   (CMValidImageProcPtr		userRoutine);
EXTERN_API(CMGetImageSpaceUPP)
NewCMGetImageSpaceProc		   (CMGetImageSpaceProcPtr	userRoutine);
EXTERN_API(CMEmbedImageUPP)
NewCMEmbedImageProc			   (CMEmbedImageProcPtr		userRoutine);
EXTERN_API(CMUnembedImageUPP)
NewCMUnembedImageProc		   (CMUnembedImageProcPtr	userRoutine);
EXTERN_API(CMMatchImageUPP)
NewCMMatchImageProc			   (CMMatchImageProcPtr		userRoutine);
EXTERN_API(CMProofImageUPP)
NewCMProofImageProc			   (CMProofImageProcPtr		userRoutine);
EXTERN_API(CMLinkImageUPP)
NewCMLinkImageProc			   (CMLinkImageProcPtr		userRoutine);
EXTERN_API(CMCountImageProfilesUPP)
NewCMCountImageProfilesProc	   (CMCountImageProfilesProcPtr userRoutine);
EXTERN_API(CMGetIndImageProfileUPP)
NewCMGetIndImageProfileProc	   (CMGetIndImageProfileProcPtr userRoutine);
EXTERN_API(CMSetIndImageProfileUPP)
NewCMSetIndImageProfileProc	   (CMSetIndImageProfileProcPtr userRoutine);
EXTERN_API(CMError)
CallValidateImageProc		   (ValidateImageUPP		userRoutine,
								const FSSpec *			spec);
EXTERN_API(CMError)
CallGetImageSpaceProc		   (GetImageSpaceUPP		userRoutine,
								const FSSpec *			spec,
								OSType *				space);
EXTERN_API(CMError)
CallValidateSpaceProc		   (ValidateSpaceUPP		userRoutine,
								const FSSpec *			spec,
								OSType *				space);
EXTERN_API(CMError)
CallEmbedImageProc			   (EmbedImageUPP			userRoutine,
								const FSSpec *			specFrom,
								const FSSpec *			specInto,
								CMProfileRef			embedProf,
								UInt32					embedFlags);
EXTERN_API(CMError)
CallUnembedImageProc		   (UnembedImageUPP			userRoutine,
								const FSSpec *			specFrom,
								const FSSpec *			specInto);
EXTERN_API(CMError)
CallMatchImageProc			   (MatchImageUPP			userRoutine,
								const FSSpec *			specFrom,
								const FSSpec *			specInto,
								UInt32					qual,
								UInt32					srcIntent,
								CMProfileRef			srcProf,
								CMProfileRef			dstProf,
								CMProfileRef			prfProf,
								UInt32					matchFlags);
EXTERN_API(CMError)
CallCountImageProfilesProc	   (CountImageProfilesUPP	userRoutine,
								const FSSpec *			spec,
								UInt32 *				count);
EXTERN_API(CMError)
CallGetIndImageProfileProc	   (GetIndImageProfileUPP	userRoutine,
								const FSSpec *			spec,
								UInt32					index,
								CMProfileRef *			prof);
EXTERN_API(CMError)
CallSetIndImageProfileProc	   (SetIndImageProfileUPP	userRoutine,
								const FSSpec *			specFrom,
								const FSSpec *			specInto,
								UInt32					index,
								CMProfileRef			prof,
								UInt32					embedFlags);
EXTERN_API(CMError)
CallCMValidImageProc		   (CMValidImageUPP			userRoutine,
								const FSSpec *			spec);
EXTERN_API(CMError)
CallCMGetImageSpaceProc		   (CMGetImageSpaceUPP		userRoutine,
								const FSSpec *			spec,
								OSType *				space);
EXTERN_API(CMError)
CallCMEmbedImageProc		   (CMEmbedImageUPP			userRoutine,
								const FSSpec *			specFrom,
								const FSSpec *			specInto,
								Boolean					repl,
								CMProfileRef			embProf);
EXTERN_API(CMError)
CallCMUnembedImageProc		   (CMUnembedImageUPP		userRoutine,
								const FSSpec *			specFrom,
								const FSSpec *			specInto,
								Boolean					repl);
EXTERN_API(CMError)
CallCMMatchImageProc		   (CMMatchImageUPP			userRoutine,
								const FSSpec *			specFrom,
								const FSSpec *			specInto,
								Boolean					repl,
								UInt32					qual,
								CMProfileRef			srcProf,
								UInt32					srcIntent,
								CMProfileRef			dstProf);
EXTERN_API(CMError)
CallCMProofImageProc		   (CMProofImageUPP			userRoutine,
								const FSSpec *			specFrom,
								const FSSpec *			specInto,
								Boolean					repl,
								UInt32					qual,
								CMProfileRef			srcProf,
								UInt32					srcIntent,
								CMProfileRef			dstProf,
								CMProfileRef			prfProf);
EXTERN_API(CMError)
CallCMLinkImageProc			   (CMLinkImageUPP			userRoutine,
								const FSSpec *			specFrom,
								const FSSpec *			specInto,
								Boolean					repl,
								UInt32					qual,
								CMProfileRef			lnkProf,
								UInt32					lnkIntent);
EXTERN_API(CMError)
CallCMCountImageProfilesProc    (CMCountImageProfilesUPP userRoutine,
								const FSSpec *			spec,
								UInt32 *				count);
EXTERN_API(CMError)
CallCMGetIndImageProfileProc    (CMGetIndImageProfileUPP userRoutine,
								const FSSpec *			spec,
								UInt32					index,
								CMProfileRef *			prof);
EXTERN_API(CMError)
CallCMSetIndImageProfileProc    (CMSetIndImageProfileUPP userRoutine,
								const FSSpec *			specFrom,
								const FSSpec *			specInto,
								Boolean					repl,
								UInt32					index,
								CMProfileRef			prof);
#else
#define NewValidateImageProc(userRoutine) 						(ValidateImageUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppValidateImageProcInfo, GetCurrentArchitecture())
#define NewGetImageSpaceProc(userRoutine) 						(GetImageSpaceUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppGetImageSpaceProcInfo, GetCurrentArchitecture())
#define NewValidateSpaceProc(userRoutine) 						(ValidateSpaceUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppValidateSpaceProcInfo, GetCurrentArchitecture())
#define NewEmbedImageProc(userRoutine) 							(EmbedImageUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppEmbedImageProcInfo, GetCurrentArchitecture())
#define NewUnembedImageProc(userRoutine) 						(UnembedImageUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppUnembedImageProcInfo, GetCurrentArchitecture())
#define NewMatchImageProc(userRoutine) 							(MatchImageUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppMatchImageProcInfo, GetCurrentArchitecture())
#define NewCountImageProfilesProc(userRoutine) 					(CountImageProfilesUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppCountImageProfilesProcInfo, GetCurrentArchitecture())
#define NewGetIndImageProfileProc(userRoutine) 					(GetIndImageProfileUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppGetIndImageProfileProcInfo, GetCurrentArchitecture())
#define NewSetIndImageProfileProc(userRoutine) 					(SetIndImageProfileUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppSetIndImageProfileProcInfo, GetCurrentArchitecture())
#define NewCMValidImageProc(userRoutine) 						(CMValidImageUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppCMValidImageProcInfo, GetCurrentArchitecture())
#define NewCMGetImageSpaceProc(userRoutine) 					(CMGetImageSpaceUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppCMGetImageSpaceProcInfo, GetCurrentArchitecture())
#define NewCMEmbedImageProc(userRoutine) 						(CMEmbedImageUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppCMEmbedImageProcInfo, GetCurrentArchitecture())
#define NewCMUnembedImageProc(userRoutine) 						(CMUnembedImageUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppCMUnembedImageProcInfo, GetCurrentArchitecture())
#define NewCMMatchImageProc(userRoutine) 						(CMMatchImageUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppCMMatchImageProcInfo, GetCurrentArchitecture())
#define NewCMProofImageProc(userRoutine) 						(CMProofImageUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppCMProofImageProcInfo, GetCurrentArchitecture())
#define NewCMLinkImageProc(userRoutine) 						(CMLinkImageUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppCMLinkImageProcInfo, GetCurrentArchitecture())
#define NewCMCountImageProfilesProc(userRoutine) 				(CMCountImageProfilesUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppCMCountImageProfilesProcInfo, GetCurrentArchitecture())
#define NewCMGetIndImageProfileProc(userRoutine) 				(CMGetIndImageProfileUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppCMGetIndImageProfileProcInfo, GetCurrentArchitecture())
#define NewCMSetIndImageProfileProc(userRoutine) 				(CMSetIndImageProfileUPP)NewRoutineDescriptor((ProcPtr)(userRoutine), uppCMSetIndImageProfileProcInfo, GetCurrentArchitecture())
#define CallValidateImageProc(userRoutine, spec) 				CALL_ONE_PARAMETER_UPP((userRoutine), uppValidateImageProcInfo, (spec))
#define CallGetImageSpaceProc(userRoutine, spec, space) 		CALL_TWO_PARAMETER_UPP((userRoutine), uppGetImageSpaceProcInfo, (spec), (space))
#define CallValidateSpaceProc(userRoutine, spec, space) 		CALL_TWO_PARAMETER_UPP((userRoutine), uppValidateSpaceProcInfo, (spec), (space))
#define CallEmbedImageProc(userRoutine, specFrom, specInto, embedProf, embedFlags)  CALL_FOUR_PARAMETER_UPP((userRoutine), uppEmbedImageProcInfo, (specFrom), (specInto), (embedProf), (embedFlags))
#define CallUnembedImageProc(userRoutine, specFrom, specInto) 	CALL_TWO_PARAMETER_UPP((userRoutine), uppUnembedImageProcInfo, (specFrom), (specInto))
#define CallMatchImageProc(userRoutine, specFrom, specInto, qual, srcIntent, srcProf, dstProf, prfProf, matchFlags)  CALL_EIGHT_PARAMETER_UPP((userRoutine), uppMatchImageProcInfo, (specFrom), (specInto), (qual), (srcIntent), (srcProf), (dstProf), (prfProf), (matchFlags))
#define CallCountImageProfilesProc(userRoutine, spec, count) 	CALL_TWO_PARAMETER_UPP((userRoutine), uppCountImageProfilesProcInfo, (spec), (count))
#define CallGetIndImageProfileProc(userRoutine, spec, index, prof)  CALL_THREE_PARAMETER_UPP((userRoutine), uppGetIndImageProfileProcInfo, (spec), (index), (prof))
#define CallSetIndImageProfileProc(userRoutine, specFrom, specInto, index, prof, embedFlags)  CALL_FIVE_PARAMETER_UPP((userRoutine), uppSetIndImageProfileProcInfo, (specFrom), (specInto), (index), (prof), (embedFlags))
#define CallCMValidImageProc(userRoutine, spec) 				CALL_ONE_PARAMETER_UPP((userRoutine), uppCMValidImageProcInfo, (spec))
#define CallCMGetImageSpaceProc(userRoutine, spec, space) 		CALL_TWO_PARAMETER_UPP((userRoutine), uppCMGetImageSpaceProcInfo, (spec), (space))
#define CallCMEmbedImageProc(userRoutine, specFrom, specInto, repl, embProf)  CALL_FOUR_PARAMETER_UPP((userRoutine), uppCMEmbedImageProcInfo, (specFrom), (specInto), (repl), (embProf))
#define CallCMUnembedImageProc(userRoutine, specFrom, specInto, repl)  CALL_THREE_PARAMETER_UPP((userRoutine), uppCMUnembedImageProcInfo, (specFrom), (specInto), (repl))
#define CallCMMatchImageProc(userRoutine, specFrom, specInto, repl, qual, srcProf, srcIntent, dstProf)  CALL_SEVEN_PARAMETER_UPP((userRoutine), uppCMMatchImageProcInfo, (specFrom), (specInto), (repl), (qual), (srcProf), (srcIntent), (dstProf))
#define CallCMProofImageProc(userRoutine, specFrom, specInto, repl, qual, srcProf, srcIntent, dstProf, prfProf)  CALL_EIGHT_PARAMETER_UPP((userRoutine), uppCMProofImageProcInfo, (specFrom), (specInto), (repl), (qual), (srcProf), (srcIntent), (dstProf), (prfProf))
#define CallCMLinkImageProc(userRoutine, specFrom, specInto, repl, qual, lnkProf, lnkIntent)  CALL_SIX_PARAMETER_UPP((userRoutine), uppCMLinkImageProcInfo, (specFrom), (specInto), (repl), (qual), (lnkProf), (lnkIntent))
#define CallCMCountImageProfilesProc(userRoutine, spec, count) 	CALL_TWO_PARAMETER_UPP((userRoutine), uppCMCountImageProfilesProcInfo, (spec), (count))
#define CallCMGetIndImageProfileProc(userRoutine, spec, index, prof)  CALL_THREE_PARAMETER_UPP((userRoutine), uppCMGetIndImageProfileProcInfo, (spec), (index), (prof))
#define CallCMSetIndImageProfileProc(userRoutine, specFrom, specInto, repl, index, prof)  CALL_FIVE_PARAMETER_UPP((userRoutine), uppCMSetIndImageProfileProcInfo, (specFrom), (specInto), (repl), (index), (prof))
#endif
/**** CSScriptingLib API  ****/

EXTERN_API_C( CMError )
CMValidImage					(const FSSpec *			spec);

EXTERN_API_C( CMError )
CMGetImageSpace					(const FSSpec *			spec,
								 OSType *				space);

EXTERN_API_C( CMError )
CMEmbedImage					(const FSSpec *			specFrom,
								 const FSSpec *			specInto,
								 Boolean 				repl,
								 CMProfileRef 			embProf);

EXTERN_API_C( CMError )
CMUnembedImage					(const FSSpec *			specFrom,
								 const FSSpec *			specInto,
								 Boolean 				repl);

EXTERN_API_C( CMError )
CMMatchImage					(const FSSpec *			specFrom,
								 const FSSpec *			specInto,
								 Boolean 				repl,
								 UInt32 				qual,
								 CMProfileRef 			srcProf,
								 UInt32 				srcIntent,
								 CMProfileRef 			dstProf);

EXTERN_API_C( CMError )
CMProofImage					(const FSSpec *			specFrom,
								 const FSSpec *			specInto,
								 Boolean 				repl,
								 UInt32 				qual,
								 CMProfileRef 			srcProf,
								 UInt32 				srcIntent,
								 CMProfileRef 			dstProf,
								 CMProfileRef 			prfProf);

EXTERN_API_C( CMError )
CMLinkImage						(const FSSpec *			specFrom,
								 const FSSpec *			specInto,
								 Boolean 				repl,
								 UInt32 				qual,
								 CMProfileRef 			lnkProf,
								 UInt32 				lnkIntent);

EXTERN_API_C( CMError )
CMCountImageProfiles			(const FSSpec *			spec,
								 UInt32 *				count);

EXTERN_API_C( CMError )
CMGetIndImageProfile			(const FSSpec *			spec,
								 UInt32 				index,
								 CMProfileRef *			prof);

EXTERN_API_C( CMError )
CMSetIndImageProfile			(const FSSpec *			specFrom,
								 const FSSpec *			specInto,
								 Boolean 				repl,
								 UInt32 				index,
								 CMProfileRef 			prof);


#if PRAGMA_STRUCT_ALIGN
	#pragma options align=reset
#elif PRAGMA_STRUCT_PACKPUSH
	#pragma pack(pop)
#elif PRAGMA_STRUCT_PACK
	#pragma pack()
#endif

#ifdef PRAGMA_IMPORT_OFF
#pragma import off
#elif PRAGMA_IMPORT
#pragma import reset
#endif

#ifdef __cplusplus
}
#endif

#endif /* __CMSCRIPTINGPLUGIN__ */

